@@ -6,7 +6,7 @@
    Backend for MetaPost files
    Contributed by: Scott Pakin <scott+ps2ed_AT_pakin.org>
 
-   Copyright (C) 1993 - 2021 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2023 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,14 +27,7 @@
 
 
 #include "drvbase.h"
-
-
-#ifdef HAVE_STL
 #include <string>        // C++ string class
-#else
-typedef RSString string;
-#endif
-
 
 class drvMPOST : public drvbase {
 
