@@ -5,7 +5,7 @@
    drvTGIF.h : This file is part of pstoedit
    Interface for new driver backends
 
-   Copyright (C) 1993 - 2021 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2023 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ public:
 	public:
 			OptionT < bool, BoolTrueExtractor> 		textAsAttribute; // show text a HREF attribute
 			DriverOptions() :
-				textAsAttribute(true,"-ta",nullptr,0,"text as attribute",nullptr,false)
+				textAsAttribute(true,"-ta","",0,"text as attribute",nullptr,false)
 			{
 				ADD(textAsAttribute);
 			}
