@@ -7,7 +7,7 @@
 
    drvsample.cpp : Backend for TK
 
-   Copyright (C) 1993 - 2021 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2023 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -937,8 +937,8 @@ void drvTK::print_coords()
 {
 	for (unsigned int n = 0; n < numberOfElementsInPath(); n++) {
 		const Point & p = pathElement(n).getPoint(0);
-		const float pc_x = (p.x_ + x_offset) ;
-		const float pc_y = (currentDeviceHeight - p.y_ + y_offset) ;
+		const float pc_x = (p.x() + x_offset) ;
+		const float pc_y = (currentDeviceHeight - p.y() + y_offset) ;
 		buffer << pc_x;
 		buffer << ' ' << pc_y;
 		if (n != numberOfElementsInPath() - 1) {
@@ -1093,7 +1093,7 @@ static DriverDescriptionT < drvTK > D_tk("tk", "tk and/or tk applet source code"
 										 false,	// backend supports curves
 										 false,	// backend supports elements which are filled and have edges
 										 true,	// backend supports text
-										 DriverDescription::noimage,	// no support for PNG file images
-										 DriverDescription::normalopen, true,	// backend support multiple pages
+										 DriverDescription::imageformat::noimage,	// no support for PNG file images
+										 DriverDescription::opentype::normalopen, true,	// backend support multiple pages
 										 false  /*clipping */
 										 );
